import { createInputMiddleware, initTRPC, TRPCError } from "@trpc/server"
import { prismaClient } from "../prisma"
import type { Response } from "express"

export interface Context {
	user: {
		id: string
		name: string
	} | null
	res?: Response
}

export async function createContext(authenticationToken: string | null, res: Response | undefined): Promise<Context> {
	let user: Context["user"] = null

	if (authenticationToken !== null && authenticationToken.length > 0) {
		user = await prismaClient.user.findUnique({
			where: { token: authenticationToken },
			select: {
				id: true,
				name: true
			}
		})
	}

	return {
		user,
		res
	}
}

export const t = initTRPC.context<Context>().create()

export const requireAuthentication = t.middleware(({ ctx, next }) => {
	let user = ctx.user
	if (user === null) throw new TRPCError({ code: "UNAUTHORIZED" })

	return next({
		ctx: {
			...ctx,
			user
		}
	})
})