interface SpecialCardMeta {
	type: "single-use" | "permanent"
	description: string
	weight: number
}

export type SpecialCardId =
	| "return-last-opponent" | "return-last-own" | "increase-target-by-2" | "decrease-target-by-2" | "next-round-covert" | "double-draw" | "force-hit"

export const specialCardsMeta: Record<SpecialCardId, SpecialCardMeta> = {
	"return-last-opponent": {
		type: "single-use",
		description: "Return the last card your opponent drew to the stack.",
		weight: 5
	},
	"return-last-own": {
		type: "single-use",
		description: "Return the last card you drew to the stack.",
		weight: 4
	},
	"increase-target-by-2": {
		type: "permanent",
		description: "Increases the target card value by two.",
		weight: 1
	},
	"decrease-target-by-2": {
		type: "permanent",
		description: "Decreases the target card value by two.",
		weight: 1
	},
	"next-round-covert": {
		type: "permanent",
		description: "The next card you’ll draw will be covert.",
		weight: 2
	},
	"double-draw": {
		type: "permanent",
		description: "You will draw two number cards at once.",
		weight: 5
	},
	"force-hit": {
		type: "permanent",
		description: "Your opponent is not allowed to stay",
		weight: 3
	}
}

export const specialCardIds = Object.keys(specialCardsMeta) as SpecialCardId[]

const weightedSpecialCardIds: SpecialCardId[] = []

for (const id of specialCardIds) {
	const meta = specialCardsMeta[id]

	for (let i = 0; i < meta.weight; i++) {
		weightedSpecialCardIds.push(id)
	}
}

export { weightedSpecialCardIds }